@@ -272,13 +272,17 @@ out:
 }
 
 static gboolean
-gcm_calib_set_extra_metadata (const gchar *filename, GError **error)
+gcm_calib_set_extra_metadata (GcmCalibratePriv *calib,
+			      const gchar *filename,
+			      GError **error)
 {
 	cmsHANDLE dict = NULL;
 	cmsHPROFILE lcms_profile;
 	gboolean ret = TRUE;
 	gchar *data = NULL;
+	gchar *screen_brightness_str = NULL;
 	gsize len;
+	guint percentage;
 
 	/* parse */
 	ret = g_file_get_contents (filename, &data, &len, error);
@@ -306,6 +310,21 @@ gcm_calib_set_extra_metadata (const gchar *filename, GError **error)
 	_cmsDictAddEntryAscii (dict,
 			       CD_PROFILE_METADATA_DATA_SOURCE,
 			       CD_PROFILE_METADATA_DATA_SOURCE_CALIB);
+	_cmsDictAddEntryAscii (dict,
+			       CD_PROFILE_METADATA_MEASUREMENT_DEVICE,
+			       cd_sensor_kind_to_string (cd_sensor_get_kind (calib->sensor)));
+	_cmsDictAddEntryAscii (dict,
+			       CD_PROFILE_METADATA_MAPPING_DEVICE_ID,
+			       cd_device_get_id (calib->device));
+
+	/* add the calibration brightness if an internal panel */
+	percentage = gcm_calibrate_get_screen_brightness (calib->calibrate);
+	if (percentage > 0) {
+		screen_brightness_str = g_strdup_printf ("%i", percentage);
+		_cmsDictAddEntryAscii (dict,
+				       CD_PROFILE_METADATA_SCREEN_BRIGHTNESS,
+				       screen_brightness_str);
+	}
 
 	/* just write dict */
 	ret = cmsWriteTag (lcms_profile, cmsSigMetaTag, dict);
@@ -327,6 +346,7 @@ gcm_calib_set_extra_metadata (const gchar *filename, GError **error)
 	cmsSaveProfileToFile (lcms_profile, filename);
 	ret = TRUE;
 out:
+	g_free (screen_brightness_str);
 	g_free (data);
 	if (dict != NULL)
 		cmsDictFree (dict);
@@ -374,7 +394,7 @@ gcm_calib_start_idle_cb (gpointer user_data)
 	}
 
 	/* set some private properties */
-	ret = gcm_calib_set_extra_metadata (filename, &error);
+	ret = gcm_calib_set_extra_metadata (calib, filename, &error);
 	if (!ret) {
 		g_warning ("failed to set extra metadata: %s",
 			   error->message);
@@ -1077,6 +1097,9 @@ gcm_calib_reference_kind_combobox_cb (GtkComboBox *combo_box,
 
 	/* not sorted so we can just use the index */
 	reference_kind = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box));
+	g_object_set (calib->calibrate,
+		      "reference-kind", reference_kind,
+		      NULL);
 	filename = gcm_calib_reference_kind_to_image_filename (reference_kind);
 
 	/* fallback */
