@@ -68,6 +68,7 @@ struct _GcmCalibratePrivate
 	gchar				*device;
 	gchar				*working_path;
 	guint				 old_brightness;
+	guint				 new_brightness;
 	guint				 target_whitepoint;
 	GtkWidget			*content_widget;
 	GtkWindow			*sample_window;
@@ -193,6 +194,15 @@ gcm_calibrate_get_basename (GcmCalibrate *calibrate)
 	return calibrate->priv->basename;
 }
 
+/**
+ * gcm_calibrate_get_screen_brightness:
+ **/
+guint
+gcm_calibrate_get_screen_brightness (GcmCalibrate *calibrate)
+{
+	return calibrate->priv->new_brightness;
+}
+
 /**
  * gcm_calibrate_set_basename:
  **/
@@ -1489,8 +1499,10 @@ gcm_calibrate_set_brightness (GcmCalibrate *calibrate, CdDevice *device)
 			   error->message);
 		g_clear_error (&error);
 	}
+	/* FIXME: allow the user to set this */
+	calibrate->priv->new_brightness = 100;
 	ret = gcm_brightness_set_percentage (calibrate->priv->brightness,
-					     100,
+					     calibrate->priv->new_brightness,
 					     &error);
 	if (!ret) {
 		g_warning ("failed to set brightness: %s",
@@ -2218,6 +2230,9 @@ gcm_calibrate_set_property (GObject *object, guint prop_id, const GValue *value,
 	case PROP_DISPLAY_KIND:
 		priv->display_kind = g_value_get_uint (value);
 		break;
+	case PROP_REFERENCE_KIND:
+		priv->reference_kind = g_value_get_uint (value);
+		break;
 	case PROP_WORKING_PATH:
 		g_free (priv->working_path);
 		priv->working_path = g_strdup (g_value_get_string (value));
@@ -2245,7 +2260,7 @@ gcm_calibrate_class_init (GcmCalibrateClass *klass)
 
 	pspec = g_param_spec_uint ("reference-kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
-				   G_PARAM_READABLE);
+				   G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_REFERENCE_KIND, pspec);
 
 	pspec = g_param_spec_uint ("display-kind", NULL, NULL,
