@@ -777,6 +777,13 @@ struct {
 	{ CD_PROFILE_METADATA_DATA_SOURCE,		N_("Data source type") },
 	{ CD_PROFILE_METADATA_MAPPING_FORMAT,		N_("Mapping format") },
 	{ CD_PROFILE_METADATA_MAPPING_QUALIFIER,	N_("Mapping qualifier") },
+	{ CD_PROFILE_METADATA_MAPPING_DEVICE_ID,	N_("Mapping device") },
+	{ CD_PROFILE_METADATA_ACCURACY_DE76_AVG,	N_("Delta-E average") },
+	{ CD_PROFILE_METADATA_ACCURACY_DE76_MAX,	N_("Delta-E maximum") },
+	{ CD_PROFILE_METADATA_ACCURACY_DE76_RMS,	N_("Delta-E RMS") },
+	{ CD_PROFILE_METADATA_MEASUREMENT_DEVICE,	N_("Calibration device") },
+	{ CD_PROFILE_METADATA_SCREEN_SURFACE,		N_("Screen surface finish") },
+	{ CD_PROFILE_METADATA_CONNECTION_TYPE,		N_("Connection type") },
 	{ NULL, NULL }
 };
 
@@ -797,23 +804,23 @@ gcm_viewer_is_blacklisted_metadata_key (const gchar *key)
 {
 	guint i;
 	const gchar *blacklist[] = { "prefix",
-				     "EDID_blue_x",
-				     "EDID_blue_y",
+				     "EDID_blue*",
 				     "EDID_date",
 				     "EDID_gamma",
-				     "EDID_green_x",
-				     "EDID_green_y",
+				     "EDID_green*",
 				     "EDID_mnft_id",
 				     "EDID_model_id",
-				     "EDID_red_x",
-				     "EDID_red_y",
-				     "EDID_white_x",
-				     "EDID_white_y",
+				     "EDID_red*",
+				     "EDID_white*",
+				     "OSD_*",			/* OSD controls... */
 				     "vcgt",
+				     "model",
 				     NULL };
 	for (i = 0; blacklist[i] != NULL; i++) {
-		if (g_strcmp0 (blacklist[i], key) == 0)
+		if (g_regex_match_simple (blacklist[i],
+					  key, 0, 0)) {
 			return FALSE;
+		}
 	}
 	return TRUE;
 }
@@ -855,6 +862,8 @@ gcm_viewer_add_metadata (GcmViewerPrivate *viewer,
 			continue;
 		key = gcm_viewer_get_localised_metadata_key ((gchar *) l->data);
 		value = g_hash_table_lookup (metadata, l->data);
+		if (value == NULL || value[0] == '\0')
+			continue;
 		g_debug ("Adding '%s', '%s'",
 			 key, value);
 		gtk_list_store_append (viewer->liststore_metadata, &iter);
@@ -881,6 +890,7 @@ static void
 gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 {
 	GtkWidget *widget;
+	GtkWindow *window;
 	GFile *file;
 	GcmProfile *gcm_profile = NULL;
 	GcmClut *clut_trc = NULL;
@@ -889,6 +899,7 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	const gchar *profile_manufacturer;
 	const gchar *profile_model ;
 	const gchar *profile_datetime;
+	const gchar *profile_title;
 	gchar *temp;
 	const gchar *filename;
 	gchar *basename = NULL;
@@ -1032,6 +1043,11 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 		gtk_label_set_label (GTK_LABEL (widget), _("No"));
 	}
 
+	/* set title */
+	window = GTK_WINDOW (gtk_builder_get_object (viewer->builder, "dialog_viewer"));
+	profile_title = cd_profile_get_title (profile);
+	gtk_window_set_title (window, profile_title);
+
 	/* set basename */
 	filename = cd_profile_get_filename (profile);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_filename"));
